@@ -60,14 +60,14 @@ def func(uri):
     # This will run in a thread. Create a proxy just for this thread:
     with Proxy(uri) as p:
         processed = p.delay()
-        print("[ thread %s called delay, processed by: %s ]  " % (threading.current_thread().getName(), processed))
+        print("[ thread %s called delay, processed by: %s ]  " % (threading.current_thread().name, processed))
 
 
 serv._pyroBind()  # simplify the uri
 threads = []
 for i in range(5):
     t = threading.Thread(target=func, args=[serv._pyroUri])
-    t.setDaemon(True)
+    t.daemon = True
     threads.append(t)
     t.start()
 print("Waiting for threads to finish:")
